@@ -59,4 +59,6 @@ def push_schema(project, container):
         except requests.HTTPError, e:
             if e.response.status_code in (401, 402):
                 container.load_credentials(renew=True)
-                push_json(url, push_data, container.token)
\ No newline at end of file
+                push_json(url, push_data, container.token)
+            else:
+                raise e
\ No newline at end of file
