@@ -17,10 +17,11 @@ class Runner(object):
         self.project = project
         self.base_cmd = project.base_cmd
         self.sb_dir = project.sb_home
-        self.user = project.docker_user
         self.working_dir = project.project_dir
         self.image_id = project.image_id
         self.dns = project.docker_dns
+        self.docker_config = kwargs
+        self.entrypoint = project.docker_entrypoint
 
     def run(self, command):
         volumes = {'/sb': {}, Runner.WORKING_DIR: {}}
@@ -31,8 +32,9 @@ class Runner(object):
         config['Volumes'] = volumes
         config['WorkingDir'] = Runner.WORKING_DIR
         config['Dns'] = self.dns
-        # if self.user:
-        #     config['User'] = self.user
+        config['Entrypoint'] = self.entrypoint
+
+        config.update(self.docker_config)
 
         cont = self.client.create_container_from_config(config)
         self.client.start(container=cont, binds=binds)
@@ -58,7 +60,7 @@ class Runner(object):
         return Runner.PIP_INSTALL.format(pip_options)
 
     def chown(self, user=None, path=WORKING_DIR):
-        user = user or self.user
+        user = user or self.project.docker_user
         return self.run(['chown', '-R', user, path])
 
     def run_install(self):
@@ -91,8 +93,8 @@ class Runner(object):
 
 class ImageRunner(Runner):
 
-    def __init__(self, docker_client, project):
-        Runner.__init__(self, docker_client, project)
+    def __init__(self, docker_client, project, **kwargs):
+        Runner.__init__(self, docker_client, project, **kwargs)
 
     def run_wrapper(self, input_path, cwd=None):
         run_full = ['run-full', '-i', input_path]
