@@ -1,4 +1,5 @@
 import os
+import stat
 import logging
 
 from sbgsdk.job import Job
@@ -32,6 +33,7 @@ class Adun(Executor):
     def exec_wrapper_full(self, job):
         job_dir = job.job_id
         os.mkdir(job_dir)
+        os.chmod(job_dir, os.stat(job_dir).st_mode | stat.S_IROTH | stat.S_IWOTH | stat.S_IXOTH)
         os.chdir(job_dir)
         with open('__in__.json', 'w') as fp:
             logging.debug('Writing job order to %s', os.path.abspath('__in__.json'))
@@ -47,6 +49,7 @@ class Adun(Executor):
     def exec_wrapper_job(self, job):
         job_dir = job.job_id
         os.mkdir(job_dir)
+        os.chmod(job_dir, os.stat(job_dir).st_mode | stat.S_IROTH | stat.S_IWOTH | stat.S_IXOTH)
         os.chdir(job_dir)
         with open('__in__.json', 'w') as fp:
             logging.debug('Writing job order to %s', os.path.abspath('__in__.json'))
